---
category: Components
type: General
title: Button
cover: https://gw.alipayobjects.com/zos/alicdn/fNUKzY1sk/Button.svg
---

To trigger an operation.

## When To Use

A button means an operation (or a series of operations). Clicking a button will trigger corresponding business logic.

In Ant Design Vue we provide 5 types of button.

- Primary button: indicate the main action, one primary button at most in one section.
- Default button: indicate a series of actions without priority.
- Dashed button: used for adding action commonly.
- Text button: used for the most secondary action.
- Link button: used for external links.

And 4 other properties additionally.

- `danger`: used for actions of risk, like deletion or authorization.
- `ghost`: used in situations with complex background, home pages usually.
- `disabled`: when actions are not available.
- `loading`: add loading spinner in button, avoiding multiple submits too.

## API

Different button styles can be generated by setting Button properties. The recommended order is: `type` -> `shape` -> `size` -> `loading` -> `disabled`.

| Property | Description | Type | Default | Version |
| --- | --- | --- | --- | --- |
| block | option to fit button width to its parent width | boolean | `false` |  |
| danger | set the danger status of button | boolean | `false` | 2.2.0 |
| disabled | disabled state of button | boolean | `false` |  |
| ghost | make background transparent and invert text and border colors | boolean | `false` |  |
| href | redirect url of link button | string | - |  |
| htmlType | set the original html `type` of `button`, see: [MDN](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/button#attr-type) | string | `button` |  |
| icon | set the icon of button, see: Icon component | v-slot | - |  |
| loading | set the loading status of button | boolean \| { delay: number } | `false` |  |
| shape | Can be set button shape | `default` \| `circle` \| `round` | 'default' |  |
| size | set the size of button | `large` \| `middle` \| `small` | `middle` |  |
| target | same as target attribute of a, works when href is specified | string | - |  |
| type | can be set button type | `primary` \| `ghost` \| `dashed` \| `link` \| `text` \| `default` | `default` |  |

### events

| Events Name | Description                             | Arguments       | Version |
| ----------- | --------------------------------------- | --------------- | ------- |
| click       | set the handler to handle `click` event | (event) => void |         |

It accepts all props which native buttons support.

## FAQ

### How to remove space between 2 chinese characters

Following the Ant Design specification, we will add one space between if Button (exclude Text button and Link button) contains two Chinese characters only. If you don't need that, you can use [ConfigProvider](/components/config-provider/#API) to set `autoInsertSpaceInButton` as `false`.

<img src="https://gw.alipayobjects.com/zos/antfincdn/MY%26THAPZrW/38f06cb9-293a-4b42-b183-9f443e79ffea.png" style="box-shadow: none; margin: 0; width: 100px" alt="Button with two Chinese characters"  />
